==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/domain/impl/ExternalEntityInModelSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.domain.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.ExternalEntityInModel;
import io.ciera.tool.sql.ooaofooa.domain.ExternalEntityInModelSet;
import io.ciera.tool.sql.ooaofooa.domain.ExternalEntitySet;
import io.ciera.tool.sql.ooaofooa.domain.impl.ExternalEntitySetImpl;

import java.util.Arrays;
import java.util.List;


public class ExternalEntityInModelSetImpl extends InstanceSet<ExternalEntityInModelSet,ExternalEntityInModel> implements ExternalEntityInModelSet {

    // attributes
    @Override
    public void setSS_IDdeprecated( UniqueId m_SS_IDdeprecated ) throws XtumlException {
        for ( ExternalEntityInModel externalentityinmodel : this ) externalentityinmodel.setSS_IDdeprecated( m_SS_IDdeprecated );
    }
    @Override
    public void setModl_Typ( int m_Modl_Typ ) throws XtumlException {
        for ( ExternalEntityInModel externalentityinmodel : this ) externalentityinmodel.setModl_Typ( m_Modl_Typ );
    }
    @Override
    public void setEE_ID( UniqueId ref_EE_ID ) throws XtumlException {
        for ( ExternalEntityInModel externalentityinmodel : this ) externalentityinmodel.setEE_ID( ref_EE_ID );
    }
    @Override
    public void setEEmod_ID( UniqueId m_EEmod_ID ) throws XtumlException {
        for ( ExternalEntityInModel externalentityinmodel : this ) externalentityinmodel.setEEmod_ID( m_EEmod_ID );
    }


    // selections
    @Override
    public ExternalEntitySet R9_is_a_presence_in_subsystem_model_of_ExternalEntity() throws XtumlException {
        ExternalEntitySet externalentityset = new ExternalEntitySetImpl();
        for ( ExternalEntityInModel externalentityinmodel : this ) externalentityset.add( externalentityinmodel.R9_is_a_presence_in_subsystem_model_of_ExternalEntity() );
        return externalentityset;
    }


    @Override
    public ExternalEntityInModel nullElement() {
        return ExternalEntityInModelImpl.EMPTY_EXTERNALENTITYINMODEL;
    }

    @Override
    public ExternalEntityInModelSet emptySet() {
      return new ExternalEntityInModelSetImpl();
    }

    @Override
    public ExternalEntityInModelSet value() {
        return this;
    }

    @Override
    public List<ExternalEntityInModel> elements() {
        return Arrays.asList(toArray(new ExternalEntityInModel[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/domain/impl/ExternalEntityInModelSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.domain.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.ExternalEntityInModel;
import io.ciera.tool.sql.ooaofooa.domain.ExternalEntityInModelSet;
import io.ciera.tool.sql.ooaofooa.domain.ExternalEntitySet;
import io.ciera.tool.sql.ooaofooa.domain.impl.ExternalEntitySetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ExternalEntityInModelSetImpl extends InstanceSet<ExternalEntityInModelSet,ExternalEntityInModel> implements ExternalEntityInModelSet {

    public ExternalEntityInModelSetImpl() {
    }

    public ExternalEntityInModelSetImpl(Comparator<? super ExternalEntityInModel> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setEEmod_ID( UniqueId m_EEmod_ID ) throws XtumlException {
        for ( ExternalEntityInModel externalentityinmodel : this ) externalentityinmodel.setEEmod_ID( m_EEmod_ID );
    }
    @Override
    public void setSS_IDdeprecated( UniqueId m_SS_IDdeprecated ) throws XtumlException {
        for ( ExternalEntityInModel externalentityinmodel : this ) externalentityinmodel.setSS_IDdeprecated( m_SS_IDdeprecated );
    }
    @Override
    public void setEE_ID( UniqueId ref_EE_ID ) throws XtumlException {
        for ( ExternalEntityInModel externalentityinmodel : this ) externalentityinmodel.setEE_ID( ref_EE_ID );
    }
    @Override
    public void setModl_Typ( int m_Modl_Typ ) throws XtumlException {
        for ( ExternalEntityInModel externalentityinmodel : this ) externalentityinmodel.setModl_Typ( m_Modl_Typ );
    }


    // selections
    @Override
    public ExternalEntitySet R9_is_a_presence_in_subsystem_model_of_ExternalEntity() throws XtumlException {
        ExternalEntitySet externalentityset = new ExternalEntitySetImpl();
        for ( ExternalEntityInModel externalentityinmodel : this ) externalentityset.add( externalentityinmodel.R9_is_a_presence_in_subsystem_model_of_ExternalEntity() );
        return externalentityset;
    }


    @Override
    public ExternalEntityInModel nullElement() {
        return ExternalEntityInModelImpl.EMPTY_EXTERNALENTITYINMODEL;
    }

    @Override
    public ExternalEntityInModelSet emptySet() {
      return new ExternalEntityInModelSetImpl();
    }

    @Override
    public ExternalEntityInModelSet emptySet(Comparator<? super ExternalEntityInModel> comp) {
      return new ExternalEntityInModelSetImpl(comp);
    }

    @Override
    public ExternalEntityInModelSet value() {
        return this;
    }

    @Override
    public List<ExternalEntityInModel> elements() {
        return Arrays.asList(toArray(new ExternalEntityInModel[0]));
    }

}
